@@ -1,8 +1,5 @@
 #!/usr/bin/env bash
 
-# takes the tag as an argument (e.g. v0.1.0)
-#
-
 if [ -z "$1" ]; then
 	echo "Please provide a tag."
 	echo "Usage: ./release.sh v[X.Y.Z]"
@@ -12,9 +9,11 @@ fi
 echo "Preparing $1..."
 # update the version
 msg="# managed by release.sh"
-sed "s/^version = .* $msg$/version = \"${1#v}\" $msg/" -i git-cliff*/Cargo.toml
+sed -E -i "s/^version = .* $msg$/version = \"${1#v}\" $msg/" git-cliff*/Cargo.toml
+sed -E -i "s/\"version\": \".+\"/\"version\": \"${1#v}\"/" npm/git-cliff/package.json
+sed -E -i "s/\"(git-cliff-.+)\": \".+\"/\"\1\": \"${1#v}\"/g" npm/git-cliff/package.json
 # update the changelog
-sed "s/\s+\#\s(.*)\s\#\sreplace issue numbers/\\t\1/g" -E -i config/cliff.toml
+sed -E -i "s/\s+\#\s(.*)\s\#\sreplace issue numbers/\\t\1/g" config/cliff.toml
 cargo run -- --tag "$1" >CHANGELOG.md
 git restore config/cliff.toml
 git add -A && git commit -m "chore(release): prepare for $1"
